==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONDATELIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour INSPECTIONDATELIST_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONDATELIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE6" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE7" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE8" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE9" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE10" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE11" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE12" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE13" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE14" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE15" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONDATELIST_Type", propOrder = {
    "vardate1",
    "vardate2",
    "vardate3",
    "vardate4",
    "vardate5",
    "vardate6",
    "vardate7",
    "vardate8",
    "vardate9",
    "vardate10",
    "vardate11",
    "vardate12",
    "vardate13",
    "vardate14",
    "vardate15"
})
public class INSPECTIONDATELIST_Type {

    @XmlElement(name = "VARDATE1")
    protected DATETIME vardate1;
    @XmlElement(name = "VARDATE2")
    protected DATETIME vardate2;
    @XmlElement(name = "VARDATE3")
    protected DATETIME vardate3;
    @XmlElement(name = "VARDATE4")
    protected DATETIME vardate4;
    @XmlElement(name = "VARDATE5")
    protected DATETIME vardate5;
    @XmlElement(name = "VARDATE6")
    protected DATETIME vardate6;
    @XmlElement(name = "VARDATE7")
    protected DATETIME vardate7;
    @XmlElement(name = "VARDATE8")
    protected DATETIME vardate8;
    @XmlElement(name = "VARDATE9")
    protected DATETIME vardate9;
    @XmlElement(name = "VARDATE10")
    protected DATETIME vardate10;
    @XmlElement(name = "VARDATE11")
    protected DATETIME vardate11;
    @XmlElement(name = "VARDATE12")
    protected DATETIME vardate12;
    @XmlElement(name = "VARDATE13")
    protected DATETIME vardate13;
    @XmlElement(name = "VARDATE14")
    protected DATETIME vardate14;
    @XmlElement(name = "VARDATE15")
    protected DATETIME vardate15;

    /**
     * Obtient la valeur de la propriété vardate1.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE1() {
        return vardate1;
    }

    /**
     * Définit la valeur de la propriété vardate1.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE1(DATETIME value) {
        this.vardate1 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate2.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE2() {
        return vardate2;
    }

    /**
     * Définit la valeur de la propriété vardate2.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE2(DATETIME value) {
        this.vardate2 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate3.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE3() {
        return vardate3;
    }

    /**
     * Définit la valeur de la propriété vardate3.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE3(DATETIME value) {
        this.vardate3 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate4.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE4() {
        return vardate4;
    }

    /**
     * Définit la valeur de la propriété vardate4.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE4(DATETIME value) {
        this.vardate4 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate5.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE5() {
        return vardate5;
    }

    /**
     * Définit la valeur de la propriété vardate5.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE5(DATETIME value) {
        this.vardate5 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate6.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE6() {
        return vardate6;
    }

    /**
     * Définit la valeur de la propriété vardate6.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE6(DATETIME value) {
        this.vardate6 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate7.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE7() {
        return vardate7;
    }

    /**
     * Définit la valeur de la propriété vardate7.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE7(DATETIME value) {
        this.vardate7 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate8.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE8() {
        return vardate8;
    }

    /**
     * Définit la valeur de la propriété vardate8.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE8(DATETIME value) {
        this.vardate8 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate9.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE9() {
        return vardate9;
    }

    /**
     * Définit la valeur de la propriété vardate9.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE9(DATETIME value) {
        this.vardate9 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate10.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE10() {
        return vardate10;
    }

    /**
     * Définit la valeur de la propriété vardate10.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE10(DATETIME value) {
        this.vardate10 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate11.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE11() {
        return vardate11;
    }

    /**
     * Définit la valeur de la propriété vardate11.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE11(DATETIME value) {
        this.vardate11 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate12.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE12() {
        return vardate12;
    }

    /**
     * Définit la valeur de la propriété vardate12.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE12(DATETIME value) {
        this.vardate12 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate13.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE13() {
        return vardate13;
    }

    /**
     * Définit la valeur de la propriété vardate13.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE13(DATETIME value) {
        this.vardate13 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate14.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE14() {
        return vardate14;
    }

    /**
     * Définit la valeur de la propriété vardate14.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE14(DATETIME value) {
        this.vardate14 = value;
    }

    /**
     * Obtient la valeur de la propriété vardate15.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE15() {
        return vardate15;
    }

    /**
     * Définit la valeur de la propriété vardate15.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE15(DATETIME value) {
        this.vardate15 = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/INSPECTIONDATELIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for INSPECTIONDATELIST_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INSPECTIONDATELIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE6" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE7" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE8" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE9" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE10" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE11" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE12" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE13" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE14" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VARDATE15" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSPECTIONDATELIST_Type", propOrder = {
    "vardate1",
    "vardate2",
    "vardate3",
    "vardate4",
    "vardate5",
    "vardate6",
    "vardate7",
    "vardate8",
    "vardate9",
    "vardate10",
    "vardate11",
    "vardate12",
    "vardate13",
    "vardate14",
    "vardate15"
})
public class INSPECTIONDATELIST_Type {

    @XmlElement(name = "VARDATE1")
    protected DATETIME vardate1;
    @XmlElement(name = "VARDATE2")
    protected DATETIME vardate2;
    @XmlElement(name = "VARDATE3")
    protected DATETIME vardate3;
    @XmlElement(name = "VARDATE4")
    protected DATETIME vardate4;
    @XmlElement(name = "VARDATE5")
    protected DATETIME vardate5;
    @XmlElement(name = "VARDATE6")
    protected DATETIME vardate6;
    @XmlElement(name = "VARDATE7")
    protected DATETIME vardate7;
    @XmlElement(name = "VARDATE8")
    protected DATETIME vardate8;
    @XmlElement(name = "VARDATE9")
    protected DATETIME vardate9;
    @XmlElement(name = "VARDATE10")
    protected DATETIME vardate10;
    @XmlElement(name = "VARDATE11")
    protected DATETIME vardate11;
    @XmlElement(name = "VARDATE12")
    protected DATETIME vardate12;
    @XmlElement(name = "VARDATE13")
    protected DATETIME vardate13;
    @XmlElement(name = "VARDATE14")
    protected DATETIME vardate14;
    @XmlElement(name = "VARDATE15")
    protected DATETIME vardate15;

    /**
     * Gets the value of the vardate1 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE1() {
        return vardate1;
    }

    /**
     * Sets the value of the vardate1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE1(DATETIME value) {
        this.vardate1 = value;
    }

    /**
     * Gets the value of the vardate2 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE2() {
        return vardate2;
    }

    /**
     * Sets the value of the vardate2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE2(DATETIME value) {
        this.vardate2 = value;
    }

    /**
     * Gets the value of the vardate3 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE3() {
        return vardate3;
    }

    /**
     * Sets the value of the vardate3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE3(DATETIME value) {
        this.vardate3 = value;
    }

    /**
     * Gets the value of the vardate4 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE4() {
        return vardate4;
    }

    /**
     * Sets the value of the vardate4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE4(DATETIME value) {
        this.vardate4 = value;
    }

    /**
     * Gets the value of the vardate5 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE5() {
        return vardate5;
    }

    /**
     * Sets the value of the vardate5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE5(DATETIME value) {
        this.vardate5 = value;
    }

    /**
     * Gets the value of the vardate6 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE6() {
        return vardate6;
    }

    /**
     * Sets the value of the vardate6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE6(DATETIME value) {
        this.vardate6 = value;
    }

    /**
     * Gets the value of the vardate7 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE7() {
        return vardate7;
    }

    /**
     * Sets the value of the vardate7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE7(DATETIME value) {
        this.vardate7 = value;
    }

    /**
     * Gets the value of the vardate8 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE8() {
        return vardate8;
    }

    /**
     * Sets the value of the vardate8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE8(DATETIME value) {
        this.vardate8 = value;
    }

    /**
     * Gets the value of the vardate9 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE9() {
        return vardate9;
    }

    /**
     * Sets the value of the vardate9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE9(DATETIME value) {
        this.vardate9 = value;
    }

    /**
     * Gets the value of the vardate10 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE10() {
        return vardate10;
    }

    /**
     * Sets the value of the vardate10 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE10(DATETIME value) {
        this.vardate10 = value;
    }

    /**
     * Gets the value of the vardate11 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE11() {
        return vardate11;
    }

    /**
     * Sets the value of the vardate11 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE11(DATETIME value) {
        this.vardate11 = value;
    }

    /**
     * Gets the value of the vardate12 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE12() {
        return vardate12;
    }

    /**
     * Sets the value of the vardate12 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE12(DATETIME value) {
        this.vardate12 = value;
    }

    /**
     * Gets the value of the vardate13 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE13() {
        return vardate13;
    }

    /**
     * Sets the value of the vardate13 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE13(DATETIME value) {
        this.vardate13 = value;
    }

    /**
     * Gets the value of the vardate14 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE14() {
        return vardate14;
    }

    /**
     * Sets the value of the vardate14 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE14(DATETIME value) {
        this.vardate14 = value;
    }

    /**
     * Gets the value of the vardate15 property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVARDATE15() {
        return vardate15;
    }

    /**
     * Sets the value of the vardate15 property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVARDATE15(DATETIME value) {
        this.vardate15 = value;
    }

}
